@@ -41,6 +41,7 @@ class SimpleAPI(object):
     alias = None
     description = "Simple API method"
     secret_key = None
+    callback = None
 
     def __init__(self, **kwargs):
         #signals.init_api_model.send(sender=self.__class__, name="SomeName")
@@ -82,6 +83,8 @@ class SimpleAPI(object):
                 response = send_response(status="error", data=errs)
         else:
             response = send_response(status="error", data="Pre_validate error")
+        if self.callback:
+            response = callback_function(response, self.callback)
         return response
 
     def method(self):
@@ -160,6 +163,10 @@ def send_response(status, data=None, runtime=None):
     return json.dumps(response)
 
 
+def callback_function(data, name):
+    return u"{0}({1});".format(name, data)
+
+
 class ModelAPI(SimpleAPI):
     simple_api_model_id = "simple_api_model_id"
     description = "Simple API model method"
